@@ -3,17 +3,14 @@ SVMtrainInterface <- function(measurementsTrain, classesTrain, ..., verbose = 3)
 {
   if(!requireNamespace("e1071", quietly = TRUE))
     stop("The package 'e1071' could not be found. Please install it.")
-    
-  # Classifier requires matrix input data type.
-  trainingMatrix <- as.matrix(measurementsTrain)
   
   if(verbose == 3)
     message(Sys.time(), ": Fitting SVM classifier to data.")
+  allVariables <- cbind(measurementsTrain, classesTrain) 
+  trained <- e1071::svm(classesTrain ~ ., data = allVariables, probability = TRUE, ...)
   
-  trained <- e1071::svm(trainingMatrix, classesTrain, probability = TRUE, ...)
-  
-  if(ncol(trainingMatrix) == 1) # Handle inconsistency by e1071 to not always name columns.
-      colnames(trained[["SV"]]) <- colnames(trainingMatrix)
+  if(ncol(measurementsTrain) == 1) # Handle inconsistency by e1071 to not always name columns.
+      colnames(trained[["SV"]]) <- colnames(measurementsTrain)
   
   trained
 }
@@ -31,8 +28,7 @@ SVMpredictInterface <- function(model, measurementsTest, returnType = c("both",
   
   # Prediction function depends on test data having same set of columns in same order as
   # selected features used for training.
-  colnames(measurementsTest) <- make.names(colnames(measurementsTest))
-  measurementsTest <- measurementsTest[, colnames(model[["SV"]])]
+  measurementsTest <- model.matrix(~ ., data = measurementsTest)
   classPredictions <- predict(model, measurementsTest, probability = TRUE)
   
   # e1071 uses attributes to pass back probabilities. Make them a standalone variable.
